@@ -17,7 +17,7 @@ def DirKDE(x, data, h=None, wt=None):
     '''
     The q-dim directional KDE with the von Mises kernel.
     
-    Parameters:
+    Parameters
     ----------
         x: (m,d)-array
             The Eulidean coordinates of m query points on a unit hypersphere, 
@@ -34,13 +34,24 @@ def DirKDE(x, data, h=None, wt=None):
             
         wt: (n,)-array
             The weights of kernel density contributions for n directional random 
-            sample points. (Default: wt=None, that is, each data point has an equal
-            weight "1/n".)
+            sample points. (Default: wt=None, that is, each data point has an 
+            equal weight "1/n".)
     
-    Return:
+    Return
     ----------
         f_hat: (m,)-array
-            The corresponding directinal kernel density estimates at m query points.
+            The corresponding directinal kernel density estimates at m query 
+            points.
+            
+    Example
+    --------
+    >>> import numpy as np
+    >>> from sconce.utils import CirSphSampling
+    >>> from sconce.DirSCMS import DirKDE
+    >>> cir_samp = CirSphSampling(2000, lat_c=50, lon_range=[-180,180], 
+                                  sigma=0.1, pv_ax=np.array([1,0,0]))
+    >>> d_hat_dat = DirKDE(cir_samp, cir_samp, h=None)
+    >>> d_hat_dat
     '''
     n = data.shape[0]  ## Number of data points
     d = data.shape[1]  ## Euclidean Dimension of the data
@@ -75,7 +86,7 @@ def DirKDEGradLog(x, data, h=None, wt=None):
     The (Riemannian) gradient of the logarithm of the q-dim directional KDE with
     the von Mises kernel.
     
-    Parameters:
+    Parameters
     ----------
         x: (m,d)-array
             The Eulidean coordinates of m query points on a unit hypersphere, 
@@ -95,10 +106,11 @@ def DirKDEGradLog(x, data, h=None, wt=None):
             sample points. (Default: wt=None, that is, each data point has an equal
             weight "1/n".)
     
-    Return:
+    Return
     ----------
         Riem_grad_hat: (m,d)-array
-            The corresponding gradients of the log directional KDEs at m query points.
+            The corresponding gradients of the log directional KDEs at m query 
+            points.
     '''
     n = data.shape[0]  ## Number of data points
     D = data.shape[1]  ## Euclidean dimension of data points
@@ -118,6 +130,8 @@ def DirKDEGradLog(x, data, h=None, wt=None):
     
     if wt is None:
         wt = np.ones((n,1))
+    else:
+        wt = wt.reshape(n,1)
         
     Riem_grad_hat = np.zeros((x.shape[0], D))
     for i in range(x.shape[0]):
@@ -138,7 +152,7 @@ def DirMS(y_0, data, h=None, eps=1e-7, max_iter=1000, wt=None, diff_method='all'
     '''
     Directional mean shift algorithm with the von-Mises Kernel.
     
-    Parameters:
+    Parameters
     ----------
         y_0: (N,d)-array
             The Euclidean coordinates of N directional initial points in 
@@ -155,11 +169,9 @@ def DirMS(y_0, data, h=None, eps=1e-7, max_iter=1000, wt=None, diff_method='all'
         
         eps: float
             The precision parameter for stopping the mean shift iteration.
-            (Default: eps=1e-7)
         
         max_iter: int
             The maximum number of iterations for the mean shift iteration.
-            (Default: max_iter=1000)
             
         wt: (n,)-array
             The weights of kernel density contributions for n directional random 
@@ -173,9 +185,9 @@ def DirMS(y_0, data, h=None, eps=1e-7, max_iter=1000, wt=None, diff_method='all'
             differences between two consecutive sets of iteration points need 
             to be smaller than 'eps' for terminating the algorithm. When 
             diff_method='mean', only the mean difference is compared with 'eps'
-            and stop the algorithm. Default: diff_method='all'.)
+            and stop the algorithm.)
     
-    Return:
+    Return
     ----------
         MS_path: (N,d,T)-array
             The whole iterative trajectory of every initial point yielded by 
@@ -230,7 +242,7 @@ def DirSCMSLog(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
     Directional Subspace Constrained Mean Shift algorithm with log density and 
     von-Mises kernel.
     
-    Parameters:
+    Parameters
     ----------
         mesh_0: a (m,D)-array
             The Euclidean coordinates of m directional initial points in the 
@@ -241,7 +253,7 @@ def DirSCMSLog(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             D-dimensional Euclidean space.
        
         d: int
-            The order of the density ridge. (Default: d=1.)
+            The order of the density ridge.
        
         h: float
             The bandwidth parameter. (Default: h=None. Then a rule of thumb for 
@@ -249,11 +261,11 @@ def DirSCMSLog(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             is applied.)
        
         eps: float
-            The precision parameter. (Default: eps=1e-7.)
+            The precision parameter.
        
         max_iter: int
             The maximum number of iterations for the directional SCMS algorithm 
-            on each initial point. (Default: max_iter=1000.)
+            on each initial point.
             
         wt: (n,)-array
             The weights of kernel density contributions for n directional random 
@@ -267,9 +279,8 @@ def DirSCMSLog(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             'eps' for terminating the algorithm. When stop_cri='proj_grad' or 
             others, the projected/principal (Riemannian) gradient of the current 
             point need to be smaller than 'eps' for terminating the algorithm.)
-            (Default: stop_cri='proj_grad'.)
     
-    Return:
+    Return
     ----------
         SCMS_path: (m,D,T)-array
             The entire iterative DirSCMS sequence for each initial point.
@@ -352,7 +363,7 @@ def DirSCMS(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
     Directional Subspace Constrained Mean Shift Algorithm with the von-Mises 
     kernel. 
     
-    Parameters:
+    Parameters
     ----------
         mesh_0: a (m,D)-array
             The Euclidean coordinates of m directional initial points in the 
@@ -363,7 +374,7 @@ def DirSCMS(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             D-dimensional Euclidean space.
        
         d: int
-            The order of the density ridge. (Default: d=1.)
+            The order of the density ridge.
        
         h: float
             The bandwidth parameter. (Default: h=None. Then a rule of thumb for 
@@ -371,11 +382,11 @@ def DirSCMS(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             is applied.)
        
         eps: float
-            The precision parameter. (Default: eps=1e-7.)
+            The precision parameter.
        
         max_iter: int
             The maximum number of iterations for the directional SCMS algorithm 
-            on each initial point. (Default: max_iter=1000.)
+            on each initial point.
             
         wt: (n,)-array
             The weights of kernel density contributions for n directional random 
@@ -389,9 +400,8 @@ def DirSCMS(mesh_0, data, d=1, h=None, eps=1e-7, max_iter=1000, wt=None,
             'eps' for terminating the algorithm. When stop_cri='proj_grad' or 
             others, the projected/principal (Riemannian) gradient of the current 
             point need to be smaller than 'eps' for terminating the algorithm.)
-            (Default: stop_cri='proj_grad'.)
     
-    Return:
+    Return
     ----------
         SCMS_path: (m,D,T)-array
             The entire iterative DirSCMS sequence for each initial point.
